@@ -52,7 +52,7 @@ RecipeIngredientList;
 
 class RecipeDB: public TQObject, virtual public KrecipesDBIface
 {
-	Q_OBJECT
+	TQ_OBJECT
 
 public:
 	RecipeDB();
