@@ -17,7 +17,7 @@ class KProcIO;
 
 class ConvertSQLite3 : public TQObject
 {
-Q_OBJECT
+TQ_OBJECT
 
 public:
 	ConvertSQLite3( const TQString &db_file = TQString::null );
