@@ -24,7 +24,7 @@
 
 class DietViewDialog: public KDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
 
 public:
 	DietViewDialog( TQWidget *parent, const RecipeList &recipeList, int dayNumber, int mealNumber, const TQValueList <int> &dishNumbers );
