@@ -21,7 +21,7 @@ class RecipeViewDialog;
 
 class RecipePrintPreview : public KDialogBase
 {
-Q_OBJECT
+TQ_OBJECT
 
 public:
 	RecipePrintPreview( TQWidget *parent, RecipeDB *db, const TQValueList<int> &ids );
