@@ -19,7 +19,7 @@ class TQListViewItem;
 
 class RecipeFilter : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
 
 public:
 	RecipeFilter( TDEListView * );
