@@ -21,7 +21,7 @@ class RecipeDB;
 
 class CriteriaComboBox : public KComboBox
 {
-	Q_OBJECT
+	TQ_OBJECT
 
 public:
 	CriteriaComboBox( bool, TQWidget *parent, RecipeDB *db );
